@@ -9,7 +9,6 @@ __all__ = [
 
 
 class ParsedTools(TypedDict):
-    should_use_tool: Optional[bool]
     tool_name: Optional[str]
     tool_input: Optional[dict]
     final_response: Optional[str]
@@ -19,6 +18,6 @@ scratchpad: Scratchpad[ParsedTools] = Scratchpad[ParsedTools](
     """
 Tool: {tool_name:S}
 Tool Input: {tool_input:json}
-Response: {final_response}
+Response: {final_response:multiline}
 """.strip()
 )
